@@ -10,9 +10,9 @@ export default function ({width, height, ...rest}) {
   let contentWidth = width - toolbarWidth - sidebarWidth;
 
   return (
-    <div style={{display: "flex", flexFlow: "row nowrap", height}} onWheel={event => event.preventDefault()}>
+    <div style={{display: "flex", flexFlow: "row nowrap", height}}>
       <Toolbar width={toolbarWidth} height={height} {...rest} />
-      <Content width={contentWidth} height={height} {...rest} />
+      <Content width={contentWidth} height={height} {...rest} onWheel={event => event.preventDefault()} />
       <Sidebar width={sidebarWidth} height={height} {...rest} />
     </div>
   );
