@@ -1,8 +1,12 @@
-import React, {PropTypes, Component} from 'react';
+import React, {Component} from 'react';
+import PropTypes from 'prop-types';
 import Panel from '../panel';
 import {Seq} from 'immutable';
-import {MODE_VIEWING_CATALOG, MODE_CONFIGURING_PROJECT,
-  MODE_CONFIGURING_LAYER
+import {
+  MODE_IDLE, MODE_2D_ZOOM_IN, MODE_2D_ZOOM_OUT, MODE_2D_PAN, MODE_3D_VIEW, MODE_3D_FIRST_PERSON,
+  MODE_WAITING_DRAWING_LINE, MODE_DRAWING_LINE, MODE_DRAWING_HOLE, MODE_DRAWING_ITEM, MODE_DRAGGING_LINE,
+  MODE_DRAGGING_VERTEX, MODE_DRAGGING_ITEM, MODE_DRAGGING_HOLE, MODE_FITTING_IMAGE, MODE_UPLOADING_IMAGE,
+  MODE_ROTATING_ITEM
 } from '../../../constants';
 import ElementEditor from './element-editor';
 
@@ -10,7 +14,11 @@ export default function PanelElementEditor({state}, {translator}) {
 
   let {scene, mode} = state;
 
-  if ([MODE_VIEWING_CATALOG, MODE_CONFIGURING_PROJECT, MODE_CONFIGURING_LAYER].includes(mode)) return null;
+  if (![MODE_IDLE, MODE_2D_ZOOM_IN, MODE_2D_ZOOM_OUT, MODE_2D_PAN,
+      MODE_3D_VIEW, MODE_3D_FIRST_PERSON,
+      MODE_WAITING_DRAWING_LINE, MODE_DRAWING_LINE, MODE_DRAWING_HOLE, MODE_DRAWING_ITEM,
+      MODE_DRAGGING_LINE, MODE_DRAGGING_VERTEX, MODE_DRAGGING_ITEM, MODE_DRAGGING_HOLE,
+      MODE_ROTATING_ITEM, MODE_UPLOADING_IMAGE, MODE_FITTING_IMAGE].includes(mode)) return null;
 
   let componentRenderer = (element, layer) =>
     <Panel key={element.id} name={translator.t("Properties: [{0}] {1}", element.type, element.id)}>
@@ -36,6 +44,6 @@ PanelElementEditor.propTypes = {
   state: PropTypes.object.isRequired,
 };
 
-PanelElementEditor.contextTypes= {
+PanelElementEditor.contextTypes = {
   translator: PropTypes.object.isRequired
 };
